@@ -12,7 +12,8 @@ mueve_mouse = dispatch.Signal(providing_args=['x', 'y', 'dx', 'dy'])
 click_de_mouse = dispatch.Signal(providing_args=['button', 'x', 'y'])
 termina_click = dispatch.Signal(providing_args=['button', 'x', 'y'])
 mueve_rueda = dispatch.Signal(providing_args=['delta'])
-pulsa_tecla = dispatch.Signal(providing_args=['codigo'])
+pulsa_tecla = dispatch.Signal(providing_args=['codigo', 'texto'])
+suelta_tecla = dispatch.Signal(providing_args=['codigo', 'texto'])
 pulsa_tecla_escape = dispatch.Signal(providing_args=[])
 actualizar = dispatch.Signal(providing_args=[])
 post_dibujar = dispatch.Signal(providing_args=[])
