@@ -6,6 +6,7 @@
 #
 # website - http://www.pilas-engine.com.ar
 
+import os
 import sys
 import copy
 from PyQt4 import QtGui, QtCore
@@ -16,7 +17,7 @@ try:
     from PyQt4.QtOpenGL import QGLWidget
 except ImportError:
     QGLWidget = object
-    print "No se encuentra OpenGL en este equipo."
+    print "No se encuentra soporte OpenGL en este equipo."
 
 
 import motor
@@ -31,7 +32,7 @@ from pilas import simbolos
 from pilas import colores
 
 
-class BaseActor:
+class BaseActor(object):
     
     def __init__(self):
         self._rotacion = 0
@@ -73,9 +74,10 @@ class BaseActor:
     def set_espejado(self, espejado):        
         self._espejado = espejado
         
-class QtImagen():
+class QtImagen(object):
 
     def __init__(self, ruta):
+        self.ruta_original = ruta
         self._imagen = QtGui.QPixmap(ruta)
 
     def ancho(self):
@@ -115,6 +117,10 @@ class QtImagen():
     def _dibujar_pixmap(self, motor, x, y):
         motor.canvas.drawPixmap(x, y, self._imagen)
 
+    def __str__(self):
+        nombre_imagen = os.path.basename(self.ruta_original)
+        return "<Imagen del archivo '%s'>" %(nombre_imagen)
+
 
 class QtGrilla(QtImagen):
 
@@ -408,6 +414,7 @@ class QtSonido:
     def __init__(self, ruta):
         import pygame
         pygame.mixer.init()
+        pygame.mixer.init()
         self.sonido = pygame.mixer.Sound(ruta)
 
     def reproducir(self):
@@ -415,77 +422,6 @@ class QtSonido:
         # print "Usando pygame para reproducir sonido"
         self.sonido.play()
         
-class SFMLCanvas:
-    "Representa una superficie sobre la que se puede dibujar usando cairo."
-    # TODO
-
-    def __init__(self, ancho, alto):
-        self.ancho = ancho
-        self.alto = alto
-        self.surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, ancho, alto)
-        self.image = sf.Image()
-        self.context = cairo.Context(self.surface)
-        self.actualizar()
-
-    def actualizar(self):
-        self.image.LoadFromPixels(self.ancho, self.alto, self.surface.get_data())
-
-    def limpiar(self):
-        self.surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, self.ancho, self.alto)
-        self.context = cairo.Context(self.surface)       
-
-               
-
-    def __init__(self, ancho, alto, titulo):
-        super(Ventana, self).__init__()
-        self.init()
-        self.sprites = []
-
-        '''
-        self.mouse = QtGui.QCursor()
-
-        time = QtCore.QTimer()
-        time.singleShot(50, self.hacer_flotante_la_ventana_en_i3)
-        '''
-
-    def do_update(self):
-        self.update()
-        '''
-        position = self.mapFromGlobal(QtGui.QCursor.pos())
-        x = position.x()
-        y = position.y()
-        self.sprites[0].x = x
-        self.sprites[0].y = y
-        '''
-
-    def hacer_flotante_la_ventana_en_i3(self):
-        try:
-            subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        except OSError:
-            pass
-
-    def paintEvent(self, event):
-        self.canvas.begin(self)
-        #self.qp.scale(self.scale_x, self.scale_y)
-        self.canvas.setClipRect(0, 0, 640, 480)
-
-        # Hace que el centro de coordenadas sea (0, 0)
-        # self.qp.setWindow(-320, -240, 640, 480)
-        # self.qp.setRenderHint(QtGui.QPainter.HighQualityAntialiasing, True)
-        self.render(event, self.canvas)
-        self.canvas.end()
-
-    def keyPressEvent(self, event):
-        print "Pulsa la tecla:", event.key()
-
-    def wheelEvent(self, event):
-        print "Mueve rueda:", event.delta()
-
-
-    def render(self, event, qp):
-        for r in self.sprites:
-            r.dibujar(self.canvas)
-        
 class QtBase(motor.Motor):
     
     app = QtGui.QApplication([])
@@ -517,7 +453,26 @@ class QtBase(motor.Motor):
             self.show()
 
         # Activa la invocacion al evento timerEvent.
-        self.startTimer(1000/100.0)
+        self.startTimer(1000/60.0)
+
+    def pantalla_completa(self):
+        self.showFullScreen()
+
+    def pantalla_modo_ventana(self):
+        self.showNormal()
+
+    def esta_en_pantalla_completa(self):
+        return self.isFullScreen()
+
+    def alternar_pantalla_completa(self):
+        """Permite cambiar el modo de video.
+
+        Si está en modo ventana, pasa a pantalla completa y viceversa.
+        """
+        if self.esta_en_pantalla_completa():
+            self.pantalla_modo_ventana()
+        else:
+            self.pantalla_completa()
 
     def centro_fisico(self):
         "Centro de la ventana para situar el punto (0, 0)"
@@ -538,94 +493,9 @@ class QtBase(motor.Motor):
     def obtener_texto(self, texto, magnitud):
         return QtTexto(texto, magnitud, self)
 
-    def obtener_posicion_del_mouse(self):
-        #return (self.mouse_x, self.mouse_y)
-        pass
-    
-    def obtener_canvas(self, ancho, alto):
-        return SFMLCanvas(ancho, alto)
-    
     def obtener_grilla(self, ruta, columnas, filas):
         return QtGrilla(ruta, columnas, filas)
 
-
-    def ocultar_puntero_del_mouse(self):
-        self.ventana.ShowMouseCursor(False)
-
-    def mostrar_puntero_del_mouse(self):
-        self.ventana.ShowMouseCursor(True)
-
-    def cerrar_ventana(self):
-        self.ventana.Close()
-
-
-
-    def procesar_y_emitir_eventos(self):
-        "Procesa todos los eventos que la biblioteca SFML pone en una cola."
-        return
-        '''
-        pass
-        event = self.event
-
-        while self.ventana.GetEvent(self.event):
-            if event.Type == sf.Event.Closed:
-                pilas.mundo.terminar()
-            if event.Type == sf.Event.KeyPressed:
-                self.procesar_evento_teclado(event)
-
-                if event.Key.Code == sf.Key.Q and event.Key.Alt:
-                    pilas.mundo.terminar()
-            elif event.Type == sf.Event.TextEntered:
-
-                eventos.pulsa_tecla.send("ejecutar", codigo=unichr(event.Text.Unicode)) 
-            elif event.Type == sf.Event.MouseMoved:
-                # Notifica el movimiento del mouse con una señal
-
-                x, y = event.MouseMove.X, event.MouseMove.Y
-
-                if x > 0 and y > 0:
-                    x, y = self.ventana.ConvertCoords(x, y)
-                    y = -y
-
-                    # Se asegura de los eventos de mouse esten siempre
-                    # dentro de la ventana.
-                    x = min(320, x)
-                    y = max(y, -240)
-
-                    dx = x - self.mouse_x
-                    dy = y - self.mouse_y
-
-                    self.mouse_x = x
-                    self.mouse_y = y
-
-                    eventos.mueve_mouse.send("ejecutar", x=x, y=y, dx=dx, dy=dy)
-
-            elif event.Type == sf.Event.MouseButtonPressed:
-                x, y = self.ventana.ConvertCoords(event.MouseButton.X, event.MouseButton.Y)
-                eventos.click_de_mouse.send("ejecutar", button=event.MouseButton.Button, x=x, y=-y)
-            elif event.Type == sf.Event.MouseButtonReleased:
-                x, y = self.ventana.ConvertCoords(event.MouseButton.X, event.MouseButton.Y)
-                eventos.termina_click.send("ejecutar", button=event.MouseButton.Button, x=x, y=-y)
-            elif event.Type == sf.Event.MouseWheelMoved:
-                eventos.mueve_rueda.send("ejecutar", delta=event.MouseWheel.Delta)
-        '''
-
-    def procesar_evento_teclado(self, event):
-        code = event.Key.Code
-        
-        if code == sf.Key.P and event.Key.Alt:
-            pilas.mundo.alternar_pausa()
-        elif code == sf.Key.F4:
-            pilas.motor.guardar_captura()
-        elif code == sf.Key.F6:
-            pilas.utils.listar_actores_en_consola()                
-        elif code == sf.Key.F7:
-            eventos.imprimir_todos()
-        elif code in [sf.Key.F8, sf.Key.F9, sf.Key.F10, sf.Key.F11, sf.Key.F12]:
-            pilas.mundo.depurador.pulsa_tecla(code)
-        elif code == sf.Key.Escape:
-            eventos.pulsa_tecla_escape.send("ejecutar")
-
     def actualizar_pantalla(self):
         self.ventana.update()
 
@@ -636,9 +506,6 @@ class QtBase(motor.Motor):
     def obtener_centro_de_la_camara(self):
         return (self.camara_x, self.camara_y)
 
-    def pintar(self, color):
-        pass
-            
     def cargar_sonido(self, ruta):
         return QtSonido(ruta)
 
@@ -651,37 +518,19 @@ class QtBase(motor.Motor):
     def obtener_superficie(self, ancho, alto):
         return QtSuperficie(ancho, alto)
 
-    def guardar_captura(self):
-        imagen = self.ventana.Capture()
-        numero = self._obtener_numeracion_siguiente_imagen()
-        nombre = "imagen_%d.png" %(numero)
-        imagen.SaveToFile(nombre)
-        print "Guardando el archivo %s" %(nombre)
-
-    def _obtener_numeracion_siguiente_imagen(self):
-        "Obtiene un numero de imagen para guardar una captura."
-        lista_de_archivos = glob.glob("imagen_*.png")
-
-        if lista_de_archivos:
-            archivos = "\n".join(lista_de_archivos)
-            patron = "_(.+).png"
-            numeros = [int(x) for x in re.findall(patron, archivos)]
-            numeros.sort()
-            ultimo_numero = numeros[-1] + 1
-        else:
-            ultimo_numero = 1
-
-        return ultimo_numero
-
     def ejecutar_bucle_principal(self, mundo, ignorar_errores):
         sys.exit(self.app.exec_())
 
     def paintEvent(self, event):
         self.canvas.begin(self)
 
+        self.canvas.setClipping(True)
+        self.canvas.setClipRect(0, 0, self.alto * self.ancho_original / self.alto_original, self.alto)
+
         alto = self.alto / float(self.alto_original)
         self.canvas.scale(alto, alto)
 
+
         self.canvas.setRenderHint(QtGui.QPainter.HighQualityAntialiasing, False)
         self.canvas.setRenderHint(QtGui.QPainter.SmoothPixmapTransform, True)
         self.canvas.setRenderHint(QtGui.QPainter.Antialiasing, False)
@@ -753,6 +602,8 @@ class QtBase(motor.Motor):
             eventos.pulsa_tecla_escape.send("Qt::keyPressEvent")
         if event.key() == QtCore.Qt.Key_P:
             self.alternar_pausa()
+        if event.key() == QtCore.Qt.Key_F:
+            self.alternar_pantalla_completa()
 
         eventos.pulsa_tecla.send("Qt::keyPressEvent", codigo=codigo_de_tecla, texto=event.text())
 
@@ -807,7 +658,6 @@ class QtBase(motor.Motor):
 
         return ancho, alto
 
-
     def alternar_pausa(self):
         if self.pausa_habilitada:
             self.pausa_habilitada = False
@@ -835,6 +685,11 @@ class QtGL(QtBase, QGLWidget):
 
         QGLWidget.__init__(self)
         QtBase.__init__(self)
+        self._pintar_fondo_negro()
+
+    def _pintar_fondo_negro(self):
+        color = QtGui.QColor(99, 0, 0)
+        self.setStyleSheet("QWidget { background-color: %s }" % color.name())
 
 if QGLWidget == object:
     QtGL = Qt
